/*
 * EnumValueTest.java
 * Part of the B'am library - a collection of general-purpose utility classes.
 * 
 * Copyright (C)2006 Stephen Battey
 * Contact: resource@lucidviews.net
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 */

package net.lucidviews.util;

import java.util.NoSuchElementException;


/**
 * Test harness for the <code>EnumValue</code> and <code>Enumeration</code>
 * classes.
 * <br />
 * <br />
 * @author Stephen Battey
 * @version $Revision: 1.2 $
 * @since 1.0
 */
public class EnumValueTest
{

	/*
	 * Test harness
	 */

	public static void main( String[] args )
	{
		System.out.println( "EnumValue Test: Start" );


		/* TEST 1: EnumValue.toString */
		// 1.1: with text value
		if (!DistanceUnit.YARD.toString().equals( "yard" ))
			System.out.println( "FAIL 1.1.1: " + DistanceUnit.YARD.toString() );
		if (!GardenRegion.YARD.toString().equals( "yard" ))
			System.out.println( "FAIL 1.1.2: " + GardenRegion.YARD.toString() );
		// 1.2: without text value
		if (!DistanceUnit.MILE.toString().equals( "2" ))
			System.out.println( "FAIL 1.2.1: " + DistanceUnit.MILE.toString() );
		if (!GardenRegion.FLOWER_BED.toString().equals( "0" ))
			System.out.println( "FAIL 1.2.3: " + GardenRegion.FLOWER_BED.toString() );


		/* TEST 2: EnumValue.equals */
		// 2.1: the same enum value
		if (!DistanceUnit.YARD.equals( DistanceUnit.YARD ))
			System.out.println( "FAIL 2.1.1: " + DistanceUnit.YARD );
		if (!GardenRegion.FLOWER_BED.equals( GardenRegion.FLOWER_BED ))
			System.out.println( "FAIL 2.1.2: " + GardenRegion.FLOWER_BED );
		// 2.2: different enum values
		if (DistanceUnit.MILE.equals( DistanceUnit.KILOMETRE ))
			System.out.println( "FAIL 2.2.1" );
		if (GardenRegion.FLOWER_BED.equals( GardenRegion.PATIO ))
			System.out.println( "FAIL 2.2.2" );
		// 2.3: different enum values with the same text value
		if (DistanceUnit.YARD.equals( GardenRegion.YARD ))
			System.out.println( "FAIL 2.3" );
		// 2.4: different enum values with the same index
		if (DistanceUnit.KILOMETRE.equals( GardenRegion.PATIO ))
			System.out.println( "FAIL 2.4" );
		// 2.5: matching text value
		if (!DistanceUnit.METRE.equals( "metre" ))
			System.out.println( "FAIL 2.5.1: " + DistanceUnit.METRE );
		if (!DistanceUnit.METRE.equals( "mEtRe" ))
			System.out.println( "FAIL 2.5.2: " + DistanceUnit.METRE );
		if (!GardenRegion.LAWN.equals( "lawn" ))
			System.out.println( "FAIL 2.5.3: " + GardenRegion.LAWN );
		// 2.6: matching index
		if (!DistanceUnit.METRE.equals( new Integer( 1 ) ))
			System.out.println( "FAIL 2.6.1: " + DistanceUnit.METRE );
		if (!DistanceUnit.MILE.equals( new Integer( 2 ) ))
			System.out.println( "FAIL 2.6.2: " + DistanceUnit.MILE );
		if (!GardenRegion.FLOWER_BED.equals( new Integer( 0 ) ))
			System.out.println( "FAIL 2.6.3: " + GardenRegion.FLOWER_BED );
		if (!GardenRegion.LAWN.equals( new Integer( 1 ) ))
			System.out.println( "FAIL 2.6.4: " + GardenRegion.LAWN );
		// 2.7: incorrect text value
		if (DistanceUnit.METRE.equals( "metr" ))
			System.out.println( "FAIL 2.7.1: " + DistanceUnit.METRE );
		if (DistanceUnit.METRE.equals( "metres" ))
			System.out.println( "FAIL 2.7.2: " + DistanceUnit.METRE );
		if (GardenRegion.LAWN.equals( "law" ))
			System.out.println( "FAIL 2.7.3: " + GardenRegion.LAWN );
		if (GardenRegion.LAWN.equals( "lawns" ))
			System.out.println( "FAIL 2.7.4: " + GardenRegion.LAWN );
		if (GardenRegion.LAWN.equals( "lAWn" ))
			System.out.println( "FAIL 2.7.5: " + GardenRegion.LAWN );
		// 2.8: incorrect index
		if (DistanceUnit.METRE.equals( new Integer( 2 ) ))
			System.out.println( "FAIL 2.8.1: " + DistanceUnit.METRE );
		if (DistanceUnit.MILE.equals( new Integer( 1 ) ))
			System.out.println( "FAIL 2.8.2: " + DistanceUnit.MILE );
		if (GardenRegion.FLOWER_BED.equals( new Integer( 3 ) ))
			System.out.println( "FAIL 2.8.3: " + GardenRegion.FLOWER_BED );
		if (GardenRegion.LAWN.equals( new Integer( 0 ) ))
			System.out.println( "FAIL 2.8.4: " + GardenRegion.LAWN );


		/* TEST 3: Enumeration.lookupValue */
		// 3.1: matching text value
		if (DistanceUnit.ENUMERATION.lookupValue( "metre" ) != DistanceUnit.METRE)
			System.out.println( "FAIL 3.1.1: " + DistanceUnit.METRE );
		if (GardenRegion.ENUMERATION.lookupValue( "lawn" ) != GardenRegion.LAWN)
			System.out.println( "FAIL 3.1.2: " + GardenRegion.LAWN );
		// 3.2: matching index
		if (DistanceUnit.ENUMERATION.lookupValue( new Integer( 2 ) ) != DistanceUnit.MILE)
			System.out.println( "FAIL 3.2.1: " + DistanceUnit.MILE );
		if (GardenRegion.ENUMERATION.lookupValue( new Integer( 3 ) ) != GardenRegion.PATIO)
			System.out.println( "FAIL 3.2.2: " + GardenRegion.PATIO );
		// 3.3: undefined text value
		try
		{
			EnumValue ev = DistanceUnit.ENUMERATION.lookupValue( "meter" );
			System.out.println( "FAIL 3.3.1: " + ev );
		}
		catch (NoSuchElementException e)
		{
		}
		catch (Exception e)
		{
			System.out.println( "FAIL 3.3.1: " + e );
		}
		try
		{
			EnumValue ev = GardenRegion.ENUMERATION.lookupValue( "YaRd" );
			System.out.println( "FAIL 3.3.2: " + ev );
		}
		catch (NoSuchElementException e)
		{
		}
		catch (Exception e)
		{
			System.out.println( "FAIL 3.3.2: " + e );
		}
		// 3.4: undefined index
		try
		{
			EnumValue ev = DistanceUnit.ENUMERATION.lookupValue( new Integer( 4 ) );
			System.out.println( "FAIL 3.4.1: " + ev );
		}
		catch (NoSuchElementException e)
		{
		}
		catch (Exception e)
		{
			System.out.println( "FAIL 3.4.1: " + e );
		}
		try
		{
			EnumValue ev = GardenRegion.ENUMERATION.lookupValue( new Integer( 12 ) );
			System.out.println( "FAIL 3.4.2: " + ev );
		}
		catch (NoSuchElementException e)
		{
		}
		catch (Exception e)
		{
			System.out.println( "FAIL 3.4.2: " + e );
		}


		System.out.println( "EnumValue Test: Complete" );
	}



	private static class DistanceUnit extends EnumValue
	{
		public static final Enumeration ENUMERATION = new Enumeration();

		public static final DistanceUnit YARD = new DistanceUnit( "yard" );
		public static final DistanceUnit METRE = new DistanceUnit( "metre" );
		public static final DistanceUnit MILE = new DistanceUnit();
		public static final DistanceUnit KILOMETRE = new DistanceUnit();

		private DistanceUnit()
		{
			super();
		}

		private DistanceUnit( String name )
		{
			super( name );
		}

		public Enumeration getEnumeration()
		{
			return ENUMERATION;
		}
	}


	private static class GardenRegion extends EnumValue
	{
		public static final Enumeration ENUMERATION = new Enumeration();

		public static final GardenRegion FLOWER_BED = new GardenRegion();
		public static final GardenRegion LAWN = new GardenRegion( "lawn" );
		public static final GardenRegion YARD = new GardenRegion( "yard" );
		public static final GardenRegion PATIO = new GardenRegion();

		private GardenRegion()
		{
			super();
		}

		private GardenRegion( String name )
		{
			super( name, true );
		}

		public Enumeration getEnumeration()
		{
			return ENUMERATION;
		}
	}

}


/*
 * Change History
 *
 * $Log: EnumValueTest.java,v $
 * Revision 1.2  2006/09/06 20:52:02  Steve
 * Added legal disclaimer.
 *
 * Revision 1.1  2006/04/17 15:33:38  Steve
 * Initial revision.
 *
 */
